==> v7.01.tar.gz: wekan/CONTRIBUTING.md <==
## Contributing Security related

For responsible security disclosure, please follow this process:
https://github.com/wekan/wekan/blob/master/SECURITY.md

CVE Hall of Fame is at https://wekan.github.io/hall-of-fame/

## Contributing to Documentation Wiki

Please clone wiki:
```
git clone https://github.com/wekan/wekan.wiki
```
Edit .md files, and add changed files in .zip attachment
directly to comment of new issue at
https://github.com/wekan/wekan/issues 

## Contributing code

[Building WeKan and sending PR](https://github.com/wekan/wekan/wiki/Emoji).

WeKan code contributors Hall of Fame is at ChangeLog, where
GitHub usernames are mentioned with changes added:

https://github.com/wekan/wekan/blob/master/CHANGELOG.md

Changes can be like typo fixes, bugfixes, features, or anything else
like for example at open GitHub issues https://github.com/wekan/wekan/issues .
Closed issues are already fixed or implemented.

Also see other docs at wiki, for example:

https://github.com/wekan/wekan/wiki/Developer-Documentation

Do not use code formatting or linting like eslist or prettier.

Only send minimal changed code lines, that are related to feature or fix.

WeKan code has MIT license.

About 300 persons have contributed to WeKan, stats at:

https://www.openhub.net/p/wekan

WeKan maintainer xet7 checks PR for typos etc before accepting to WeKan,
so that WeKan code will still work OK.

## Contributing translations

Non-English translations are contributed only at
https://transifex.com/wekan/wekan

When adding new features, in your PR to
https://github.com/wekan/wekan/pulls
only add new English source language strings
to https://github.com/wekan/wekan/blob/master/imports/i18n/data/en.i18n.json

Maintainer of WeKan xet7 downloads all newest
translations from Transifex and adds
them to WeKan repo before making
new release.

## About WeKan Organization https://github.com/wekan

xet7 rarely adds any new members to GitHub Organization,
because xet7 prefers to check PRs.

For some repos (other than https://github.com/wekan/wekan ),
some contributors have direct commit access.

Some contributors are mentioned at this outdated page:

https://github.com/wekan/wekan/wiki/Team

==> v7.20.tar.gz: wekan/CONTRIBUTING.md <==
## About money

Not paid:

- Money is not paid for these, everyone uses their own time at their own cost:
  - Security reports, see [SECURITY.md](SECURITY.md)
  - Pull requests
  - xet7 checking pull requests
- Public Community Support
  - https://github.com/wekan/wekan/issues

Paid by customers of WeKan Team:

- Commercial Support at https://wekan.team/commercial-support/
  - Support
  - Private Chat
  - Features
  - Fixes
  - Hosting

## Contributing Security related

For responsible security disclosure, please follow this process:
https://github.com/wekan/wekan/blob/main/SECURITY.md

CVE Hall of Fame is at https://wekan.github.io/hall-of-fame/

## Contributing to Documentation Wiki

Please clone wiki:
```
git clone https://github.com/wekan/wekan.wiki
```
Edit .md files, and add changed files in .zip attachment
directly to comment of new issue at
https://github.com/wekan/wekan/issues 

## Contributing code

[Building WeKan and sending PR](https://github.com/wekan/wekan/wiki/Emoji).

WeKan code contributors Hall of Fame is at ChangeLog, where
GitHub usernames are mentioned with changes added:

https://github.com/wekan/wekan/blob/main/CHANGELOG.md

Changes can be like typo fixes, bugfixes, features, or anything else
like for example at open GitHub issues https://github.com/wekan/wekan/issues .
Closed issues are already fixed or implemented.

Also see other docs at wiki, for example:

https://github.com/wekan/wekan/wiki/Developer-Documentation

Do not use code formatting or linting like eslist or prettier.

Only send minimal changed code lines, that are related to feature or fix.

WeKan code has MIT license.

About 300 persons have contributed to WeKan, stats at:

https://www.openhub.net/p/wekan

WeKan maintainer xet7 reviews PR for typos etc before accepting to WeKan,
so that WeKan code will still work OK.

## Contributing translations

Non-English translations are contributed only at
https://transifex.com/wekan/wekan

When adding new features, in your PR to
https://github.com/wekan/wekan/pulls
only add new English source language strings
to https://github.com/wekan/wekan/blob/main/imports/i18n/data/en.i18n.json

Maintainer of WeKan xet7 downloads all newest
translations from Transifex and adds
them to WeKan repo before making
new release.

## About WeKan Organization https://github.com/wekan

Only xet7 has write access to WeKan Organization.

xet7 reviews all PRs before merging.

There has been over 300 contributors to WeKan, newest stats at:

https://www.openhub.net/p/wekan
